@@ -1,10 +1,10 @@
-import {expectType} from 'tsd';
+import {expectType, expectAssignable} from 'tsd';
 import dotProp = require('.');
 
 expectType<unknown>(dotProp.get({foo: {bar: 'unicorn'}}, 'foo.bar'));
 expectType<string | undefined>(dotProp.get<string>({foo: {bar: 'unicorn'}}, 'foo.bar'));
 expectType<unknown>(dotProp.get({foo: {bar: 'a'}}, 'foo.notDefined.deep'));
-expectType<string>(
+expectAssignable<string>(
 	dotProp.get({foo: {bar: 'a'}}, 'foo.notDefined.deep', 'default value')
 );
 expectType<unknown>(
@@ -16,4 +16,4 @@ expectType<typeof object>(dotProp.set(object, 'foo.bar', 'b'));
 
 expectType<boolean>(dotProp.has({foo: {bar: 'unicorn'}}, 'foo.bar'));
 
-expectType<void>(dotProp.delete({foo: {bar: 'a'}}, 'foo.bar'));
+expectType<boolean>(dotProp.delete({foo: {bar: 'a'}}, 'foo.bar'));
