@@ -16,6 +16,7 @@ test('get', t => {
 	t.is(dotProp.get({foo: {bar: 'a'}}, 'foo.fake'), undefined);
 	t.is(dotProp.get({foo: {bar: 'a'}}, 'foo.fake.fake2'), undefined);
 	t.is(dotProp.get({foo: {bar: 'a'}}, 'foo.fake.fake2', 'some value'), 'some value');
+	t.is(dotProp.get({foo: {}}, 'foo.fake', 'some value'), 'some value');
 	t.is(dotProp.get({'\\': true}, '\\'), true);
 	t.is(dotProp.get({'\\foo': true}, '\\foo'), true);
 	t.is(dotProp.get({'bar\\': true}, 'bar\\'), true);
@@ -30,8 +31,8 @@ test('get', t => {
 		value: 'bar',
 		enumerable: false
 	});
-	t.is(dotProp.get(fixture2, 'foo'), undefined);
-	t.is(dotProp.get({}, 'hasOwnProperty'), undefined);
+	t.is(dotProp.get(fixture2, 'foo'), 'bar');
+	t.is(dotProp.get({}, 'hasOwnProperty'), Object.prototype.hasOwnProperty);
 
 	function fn() {}
 	fn.foo = {bar: 1};
@@ -43,13 +44,18 @@ test('get', t => {
 	t.is(dotProp.get(f3, 'foo.bar'), undefined);
 	t.is(dotProp.get(f3, 'foo.bar', 'some value'), 'some value');
 
-	t.is(dotProp.get({'foo.baz': {bar: true}}, 'foo\\.baz.bar'), true);
-	t.is(dotProp.get({'fo.ob.az': {bar: true}}, 'fo\\.ob\\.az.bar'), true);
+	t.true(dotProp.get({'foo.baz': {bar: true}}, 'foo\\.baz.bar'));
+	t.true(dotProp.get({'fo.ob.az': {bar: true}}, 'fo\\.ob\\.az.bar'));
 
-	t.is(dotProp.get(null, 'foo.bar', false), false);
-	t.is(dotProp.get('foo', 'foo.bar', false), false);
-	t.is(dotProp.get([], 'foo.bar', false), false);
-	t.is(dotProp.get(undefined, 'foo.bar', false), false);
+	t.false(dotProp.get(null, 'foo.bar', false));
+	t.false(dotProp.get('foo', 'foo.bar', false));
+	t.false(dotProp.get([], 'foo.bar', false));
+	t.false(dotProp.get(undefined, 'foo.bar', false));
+
+	class F4Class {}
+	F4Class.prototype.foo = 1;
+	const f4 = new F4Class();
+	t.is(dotProp.get(f4, 'foo'), 1); // #46
 });
 
 test('set', t => {
@@ -105,7 +111,7 @@ test('set', t => {
 	t.is(fixture1['foo.bar'].baz, true);
 
 	dotProp.set(fixture1, 'fo\\.ob\\.ar.baz', true);
-	t.is(fixture1['fo.ob.ar'].baz, true);
+	t.true(fixture1['fo.ob.ar'].baz);
 
 	const fixture4 = 'noobject';
 	const output4 = dotProp.set(fixture4, 'foo.bar', 2);
@@ -135,30 +141,30 @@ test('delete', t => {
 	};
 
 	t.is(fixture1.foo.bar.baz.c, 'c');
-	dotProp.delete(fixture1, 'foo.bar.baz.c');
+	t.true(dotProp.delete(fixture1, 'foo.bar.baz.c'));
 	t.is(fixture1.foo.bar.baz.c, undefined);
 
 	t.is(fixture1.top.dog, 'sindre');
-	dotProp.delete(fixture1, 'top');
+	t.true(dotProp.delete(fixture1, 'top'));
 	t.is(fixture1.top, undefined);
 
 	t.is(fixture1.foo.bar.baz.func.foo, 'bar');
-	dotProp.delete(fixture1, 'foo.bar.baz.func.foo');
+	t.true(dotProp.delete(fixture1, 'foo.bar.baz.func.foo'));
 	t.is(fixture1.foo.bar.baz.func.foo, undefined);
 
 	t.is(fixture1.foo.bar.baz.func, func);
-	dotProp.delete(fixture1, 'foo.bar.baz.func');
+	t.true(dotProp.delete(fixture1, 'foo.bar.baz.func'));
 	t.is(fixture1.foo.bar.baz.func, undefined);
 
 	dotProp.set(fixture1, 'foo\\.bar.baz', true);
-	t.is(fixture1['foo.bar'].baz, true);
-	dotProp.delete(fixture1, 'foo\\.bar.baz');
+	t.true(fixture1['foo.bar'].baz);
+	t.true(dotProp.delete(fixture1, 'foo\\.bar.baz'));
 	t.is(fixture1['foo.bar'].baz, undefined);
 
 	const fixture2 = {};
 	dotProp.set(fixture2, 'foo.bar\\.baz', true);
-	t.is(fixture2.foo['bar.baz'], true);
-	dotProp.delete(fixture2, 'foo.bar\\.baz');
+	t.true(fixture2.foo['bar.baz']);
+	t.true(dotProp.delete(fixture2, 'foo.bar\\.baz'));
 	t.is(fixture2.foo['bar.baz'], undefined);
 
 	fixture2.dotted = {
@@ -167,38 +173,38 @@ test('delete', t => {
 			other: 'prop'
 		}
 	};
-	dotProp.delete(fixture2, 'dotted.sub.dotted\\.prop');
+	t.true(dotProp.delete(fixture2, 'dotted.sub.dotted\\.prop'));
 	t.is(fixture2.dotted.sub['dotted.prop'], undefined);
 	t.is(fixture2.dotted.sub.other, 'prop');
 
 	const fixture3 = {foo: null};
-	dotProp.delete(fixture3, 'foo.bar');
+	t.false(dotProp.delete(fixture3, 'foo.bar'));
 	t.deepEqual(fixture3, {foo: null});
 });
 
 test('has', t => {
 	const fixture1 = {foo: {bar: 1}};
-	t.is(dotProp.has(fixture1), false);
-	t.is(dotProp.has(fixture1, 'foo'), true);
-	t.is(dotProp.has({foo: 1}, 'foo'), true);
-	t.is(dotProp.has({foo: null}, 'foo'), true);
-	t.is(dotProp.has({foo: undefined}, 'foo'), true);
-	t.is(dotProp.has({foo: {bar: true}}, 'foo.bar'), true);
-	t.is(dotProp.has({foo: {bar: {baz: true}}}, 'foo.bar.baz'), true);
-	t.is(dotProp.has({foo: {bar: {baz: null}}}, 'foo.bar.baz'), true);
-	t.is(dotProp.has({foo: {bar: 'a'}}, 'foo.fake.fake2'), false);
-	t.is(dotProp.has({foo: null}, 'foo.bar'), false);
-	t.is(dotProp.has({foo: ''}, 'foo.bar'), false);
+	t.false(dotProp.has(fixture1));
+	t.true(dotProp.has(fixture1, 'foo'));
+	t.true(dotProp.has({foo: 1}, 'foo'));
+	t.true(dotProp.has({foo: null}, 'foo'));
+	t.true(dotProp.has({foo: undefined}, 'foo'));
+	t.true(dotProp.has({foo: {bar: true}}, 'foo.bar'));
+	t.true(dotProp.has({foo: {bar: {baz: true}}}, 'foo.bar.baz'));
+	t.true(dotProp.has({foo: {bar: {baz: null}}}, 'foo.bar.baz'));
+	t.false(dotProp.has({foo: {bar: 'a'}}, 'foo.fake.fake2'));
+	t.false(dotProp.has({foo: null}, 'foo.bar'));
+	t.false(dotProp.has({foo: ''}, 'foo.bar'));
 
 	function fn() {}
 	fn.foo = {bar: 1};
-	t.is(dotProp.has(fn), false);
-	t.is(dotProp.has(fn, 'foo'), true);
-	t.is(dotProp.has(fn, 'foo.bar'), true);
+	t.false(dotProp.has(fn));
+	t.true(dotProp.has(fn, 'foo'));
+	t.true(dotProp.has(fn, 'foo.bar'));
 
-	t.is(dotProp.has({'foo.baz': {bar: true}}, 'foo\\.baz.bar'), true);
-	t.is(dotProp.has({'fo.ob.az': {bar: true}}, 'fo\\.ob\\.az.bar'), true);
-	t.is(dotProp.has(undefined, 'fo\\.ob\\.az.bar'), false);
+	t.true(dotProp.has({'foo.baz': {bar: true}}, 'foo\\.baz.bar'));
+	t.true(dotProp.has({'fo.ob.az': {bar: true}}, 'fo\\.ob\\.az.bar'));
+	t.false(dotProp.has(undefined, 'fo\\.ob\\.az.bar'));
 });
 
 test('prevent setting/getting `__proto__`', t => {
